"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useAnalytics = exports.AnalyticsProvider = exports.createClient = exports.defaultConfig = void 0;

var _react = _interopRequireWildcard(require("react"));

var _logger = require("./logger");

var _store = require("./store");

var _react2 = require("redux-persist/integration/react");

var _analytics = require("./analytics");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const defaultConfig = {
  writeKey: '',
  flushAt: 20,
  flushInterval: 30,
  retryInterval: 60,
  maxBatchSize: 1000,
  maxEventsToRetry: 1000,
  trackDeepLinks: false,
  trackAppLifecycleEvents: false,
  autoAddSegmentDestination: true
};
exports.defaultConfig = defaultConfig;

const doClientSetup = async client => {
  // make sure the persisted store is fetched
  await client.bootstrapStore(); // get destination settings

  await client.getSettings(); // flush any stored events

  client.flush();
  client.flushRetry();
  client.configure(); // set up the timer/subscription for knowing when to flush events

  client.setupInterval();
  client.setupStoreSubscribe(); // set up tracking for lifecycle events

  client.setupLifecycleEvents(); // check if the app was opened from a deep link

  await client.trackDeepLinks(); // save the current installed version

  await client.checkInstalledVersion();
};

const createClient = config => {
  const logger = (0, _logger.createLogger)();

  if (typeof (config === null || config === void 0 ? void 0 : config.debug) === 'boolean') {
    if (config.debug) {
      logger.enable();
    } else {
      logger.disable();
    }
  }

  const clientConfig = { ...defaultConfig,
    ...config
  };
  const {
    store,
    persistor
  } = (0, _store.initializeStore)(config.writeKey);
  const client = new _analytics.SegmentClient({
    config: clientConfig,
    logger,
    store,
    actions: _store.actions,
    persistor
  });
  doClientSetup(client);
  return client;
};

exports.createClient = createClient;
const Context = /*#__PURE__*/(0, _react.createContext)(null);

const AnalyticsProvider = ({
  client,
  children
}) => {
  if (!client) {
    return null;
  }

  return /*#__PURE__*/_react.default.createElement(Context.Provider, {
    value: client
  }, /*#__PURE__*/_react.default.createElement(_react2.PersistGate, {
    loading: null,
    persistor: client.persistor
  }, children));
};

exports.AnalyticsProvider = AnalyticsProvider;

const useAnalytics = () => {
  const client = (0, _react.useContext)(Context);

  if (!client) {
    console.error('Segment client not configured!', 'To use the useAnalytics() hook, pass an initialized Segment client into the AnalyticsProvider'); // @ts-ignore

    return {};
  }

  return {
    screen: (...args) => client.screen(...args),
    track: (...args) => client.track(...args),
    identify: (...args) => client.identify(...args),
    flush: () => client.flush(),
    group: (...args) => client.group(...args),
    alias: (...args) => client.alias(...args),
    reset: () => client.reset()
  };
};

exports.useAnalytics = useAnalytics;
//# sourceMappingURL=client.js.map