"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.applyRawEventData = exports.createAliasEvent = exports.createGroupEvent = exports.createIdentifyEvent = exports.createScreenEvent = exports.createTrackEvent = void 0;

var _uuid = require("./uuid");

var _types = require("./types");

const createTrackEvent = ({
  event,
  properties = {}
}) => ({
  type: _types.EventType.TrackEvent,
  event,
  properties
});

exports.createTrackEvent = createTrackEvent;

const createScreenEvent = ({
  name,
  properties = {}
}) => ({
  type: _types.EventType.ScreenEvent,
  name,
  properties
});

exports.createScreenEvent = createScreenEvent;

const createIdentifyEvent = ({
  userTraits = {}
}) => {
  return {
    type: _types.EventType.IdentifyEvent,
    traits: userTraits
  };
};

exports.createIdentifyEvent = createIdentifyEvent;

const createGroupEvent = ({
  groupId,
  groupTraits = {}
}) => ({
  type: _types.EventType.GroupEvent,
  groupId,
  traits: groupTraits
});

exports.createGroupEvent = createGroupEvent;

const createAliasEvent = ({
  anonymousId,
  userId,
  newUserId
}) => ({
  type: _types.EventType.AliasEvent,
  userId: newUserId,
  previousId: userId || anonymousId
});

exports.createAliasEvent = createAliasEvent;

const isAliasEvent = event => event.type === _types.EventType.AliasEvent;

const applyRawEventData = (event, store) => {
  const {
    system,
    userInfo
  } = store.getState();
  return { ...event,
    anonymousId: userInfo.anonymousId,
    messageId: (0, _uuid.getUUID)(),
    timestamp: new Date().toISOString(),
    integrations: system.integrations,
    userId: isAliasEvent(event) ? event.userId : userInfo.userId
  };
};

exports.applyRawEventData = applyRawEventData;
//# sourceMappingURL=events.js.map