"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = checkInstalledVersion;

var _context = require("../context");

var _events = require("../events");

async function checkInstalledVersion() {
  const context = await (0, _context.getContext)(undefined);
  const previousContext = this.store.getState().main.context;
  this.store.dispatch(this.actions.main.updateContext({
    context
  }));

  if (!this.config.trackAppLifecycleEvents) {
    return;
  }

  if (!(previousContext !== null && previousContext !== void 0 && previousContext.app)) {
    const event = (0, _events.createTrackEvent)({
      event: 'Application Installed',
      properties: {
        version: context.app.version,
        build: context.app.build
      }
    });
    this.process(event);
    this.logger.info('TRACK (Application Installed) event saved', event);
  } else if (context.app.version !== previousContext.app.version) {
    const event = (0, _events.createTrackEvent)({
      event: 'Application Updated',
      properties: {
        version: context.app.version,
        build: context.app.build,
        previous_version: previousContext.app.version,
        previous_build: previousContext.app.build
      }
    });
    this.process(event);
    this.logger.info('TRACK (Application Updated) event saved', event);
  }

  const event = (0, _events.createTrackEvent)({
    event: 'Application Opened',
    properties: {
      from_background: false,
      version: context.app.version,
      build: context.app.build
    }
  });
  this.process(event);
  this.logger.info('TRACK (Application Opened) event saved', event);
}
//# sourceMappingURL=checkInstalledVersion.js.map