import { getUUID } from './uuid';
import { EventType } from './types';
export const createTrackEvent = ({
  event,
  properties = {}
}) => ({
  type: EventType.TrackEvent,
  event,
  properties
});
export const createScreenEvent = ({
  name,
  properties = {}
}) => ({
  type: EventType.ScreenEvent,
  name,
  properties
});
export const createIdentifyEvent = ({
  userTraits = {}
}) => {
  return {
    type: EventType.IdentifyEvent,
    traits: userTraits
  };
};
export const createGroupEvent = ({
  groupId,
  groupTraits = {}
}) => ({
  type: EventType.GroupEvent,
  groupId,
  traits: groupTraits
});
export const createAliasEvent = ({
  anonymousId,
  userId,
  newUserId
}) => ({
  type: EventType.AliasEvent,
  userId: newUserId,
  previousId: userId || anonymousId
});

const isAliasEvent = event => event.type === EventType.AliasEvent;

export const applyRawEventData = (event, store) => {
  const {
    system,
    userInfo
  } = store.getState();
  return { ...event,
    anonymousId: userInfo.anonymousId,
    messageId: getUUID(),
    timestamp: new Date().toISOString(),
    integrations: system.integrations,
    userId: isAliasEvent(event) ? event.userId : userInfo.userId
  };
};
//# sourceMappingURL=events.js.map