function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { DestinationPlugin } from '../plugin';
import { PluginType } from '../types';
import { chunk } from '../util';
import { sendEvents } from '../api';
export class SegmentDestination extends DestinationPlugin {
  constructor(...args) {
    super(...args);

    _defineProperty(this, "type", PluginType.destination);

    _defineProperty(this, "key", 'Segment.io');
  }

  update(_, __) {// this is where analytics-swift initalizes the HTTP client
    // no need to do this for React Native where we just use the fetch polyfill directly
    // see flush() below
  }

  identify(event) {
    this.queueEvent(event);
    return event;
  }

  track(event) {
    this.queueEvent(event);
    return event;
  }

  screen(event) {
    this.queueEvent(event);
    return event;
  }

  alias(event) {
    this.queueEvent(event);
    return event;
  }

  group(event) {
    this.queueEvent(event);
    return event;
  }

  queueEvent(event) {
    const {
      store,
      actions
    } = this.analytics;
    store.dispatch(actions.main.addEvent({
      event: event
    }));
  }

  async flush() {
    const {
      store,
      actions
    } = this.analytics;
    const state = store.getState();
    const chunkedEvents = chunk(state.main.events, 1000);
    let sentEvents = [];
    let numFailedEvents = 0;
    await Promise.all(chunkedEvents.map(async events => {
      try {
        await sendEvents({
          config: state.system.configuration,
          events
        });
        sentEvents = sentEvents.concat(events);
      } catch (e) {
        console.warn(e);
        numFailedEvents += events.length;
      } finally {
        const messageIds = sentEvents.map(evt => evt.messageId);
        store.dispatch(actions.main.deleteEventsByMessageId({
          ids: messageIds
        }));
      }
    }));

    if (sentEvents.length) {
      console.warn(`Sent ${sentEvents.length} events`);
    }

    if (numFailedEvents) {
      console.error(`Failed to send ${numFailedEvents} events.`);
    }
  }

}
//# sourceMappingURL=SegmentDestination.js.map